@@ -1,23 +1,10 @@
-/***************************************************************************
- *   Copyright 2011 Marco Martin <mart@kde.org>                            *
- *   Copyright 2011 Artur Duque de Souza <asouza@kde.org>                  *
- *   Copyright 2013 Sebastian Kügler <sebas@kde.org>                       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2011 Marco Martin <mart@kde.org>
+    SPDX-FileCopyrightText: 2011 Artur Duque de Souza <asouza@kde.org>
+    SPDX-FileCopyrightText: 2013 Sebastian Kügler <sebas@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef TOOLTIPOBJECT_H
 #define TOOLTIPOBJECT_H
@@ -124,6 +111,12 @@ class ToolTip : public QQuickItem
      */
     Q_PROPERTY(bool interactive MEMBER m_interactive WRITE setInteractive NOTIFY interactiveChanged)
 
+    /**
+     * Timeout in milliseconds after which the tooltip will hide itself.
+     * Set this value to -1 to never hide the tooltip automatically.
+     */
+    Q_PROPERTY(int timeout MEMBER m_timeout WRITE setTimeout)
+
 public:
 /// @cond INTERNAL_DOCS
     explicit ToolTip(QQuickItem *parent = nullptr);
@@ -156,6 +149,8 @@ public:
     void setActive(bool active);
 
     void setInteractive(bool interactive);
+
+    void setTimeout(int timeout);
 /// @endcond
 
 public Q_SLOTS:
@@ -218,6 +213,7 @@ private:
     bool m_active;
     bool m_interactive;
     int m_interval;
+    int m_timeout;
 
     //ToolTipDialog is not a Q_GLOBAL_STATIC because QQuickwindows as global static
     //are deleted too later after some stuff in the qml runtime has already been deleted,
