@@ -1,24 +1,11 @@
 /*
- *   Copyright 2013 by Martin Gräßlin <mgraesslin@kde.org>
+    SPDX-FileCopyrightText: 2013 Martin Gräßlin <mgraesslin@kde.org>
 
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 #include "windowthumbnail.h"
 // KF5
-#include <kwindowsystem.h>
+#include <KWindowSystem>
 // Qt
 #include <QGuiApplication>
 #include <QIcon>
@@ -137,6 +124,7 @@ WindowThumbnail::WindowThumbnail(QQuickItem *parent)
     , m_winId(0)
     , m_paintedSize(QSizeF())
     , m_thumbnailAvailable(false)
+    , m_redirecting(false)
     , m_damaged(false)
     , m_depth(0)
 #if HAVE_XCB_COMPOSITE
@@ -160,35 +148,9 @@ WindowThumbnail::WindowThumbnail(QQuickItem *parent)
 #endif
 {
     setFlag(ItemHasContents);
-    connect(this, &QQuickItem::windowChanged, [this](QQuickWindow * window) {
-        if (!window) {
-            return;
-        }
-        // restart the redirection, it might not have been active yet
-        stopRedirecting();
-        startRedirecting();
-        update();
-    });
-    connect(this, &QQuickItem::enabledChanged, [this]() {
-        if (!isEnabled()) {
-            stopRedirecting();
-            releaseResources();
-        } else if (isVisible()) {
-            startRedirecting();
-            update();
-        }
-    });
-    connect(this, &QQuickItem::visibleChanged, [this]() {
-        if (!isVisible()) {
-            stopRedirecting();
-            releaseResources();
-        } else if (isEnabled()) {
-            startRedirecting();
-            update();
-        }
-    });
+
     if (QGuiApplication *gui = dynamic_cast<QGuiApplication *>(QCoreApplication::instance())) {
-        m_xcb = (gui->platformName() == QStringLiteral("xcb"));
+        m_xcb = (gui->platformName() == QLatin1String("xcb"));
         if (m_xcb) {
             gui->installNativeEventFilter(this);
 #if HAVE_XCB_COMPOSITE
@@ -216,6 +178,42 @@ WindowThumbnail::~WindowThumbnail()
     }
 }
 
+void WindowThumbnail::itemChange(ItemChange change, const ItemChangeData &data)
+{
+    switch (change) {
+    case ItemSceneChange:
+        if (m_scene) {
+            disconnect(m_scene.data(), &QWindow::visibleChanged, this, &WindowThumbnail::sceneVisibilityChanged);
+        }
+        m_scene = data.window;
+        if (m_scene) {
+            connect(m_scene.data(), &QWindow::visibleChanged, this, &WindowThumbnail::sceneVisibilityChanged);
+            // restart the redirection, it might not have been active yet
+            stopRedirecting();
+            if (startRedirecting()) {
+                update();
+            }
+        }
+        break;
+
+    case ItemEnabledHasChanged:
+        Q_FALLTHROUGH();
+    case ItemVisibleHasChanged:
+        if (data.boolValue) {
+            if (startRedirecting()) {
+                update();
+            }
+        } else {
+            stopRedirecting();
+            releaseResources();
+        }
+        break;
+
+    default:
+        break;
+    }
+}
+
 void WindowThumbnail::releaseResources()
 {
 #if HAVE_XCB_COMPOSITE
@@ -370,7 +368,7 @@ void WindowThumbnail::iconToTexture(WindowTextureNode *textureNode)
         // fallback to plasma icon
         icon = QIcon::fromTheme(QStringLiteral("plasma"));
     }
-    QImage image = icon.pixmap(boundingRect().size().toSize()).toImage();
+    QImage image = icon.pixmap(window(), boundingRect().size().toSize()).toImage();
     textureNode->reset(window()->createTextureFromImage(image, QQuickWindow::TextureCanUseAtlas));
 }
 
@@ -843,7 +841,10 @@ void WindowThumbnail::stopRedirecting()
     if (m_winId == XCB_WINDOW_NONE) {
         return;
     }
-    xcb_composite_unredirect_window(c, m_winId, XCB_COMPOSITE_REDIRECT_AUTOMATIC);
+    if (m_redirecting) {
+        xcb_composite_unredirect_window(c, m_winId, XCB_COMPOSITE_REDIRECT_AUTOMATIC);
+    }
+    m_redirecting = false;
     if (m_damage == XCB_NONE) {
         return;
     }
@@ -852,14 +853,14 @@ void WindowThumbnail::stopRedirecting()
 #endif
 }
 
-void WindowThumbnail::startRedirecting()
+bool WindowThumbnail::startRedirecting()
 {
-    if (!m_xcb || !m_composite || !window() || window()->winId() == m_winId) {
-        return;
+    if (!m_xcb || !m_composite || !window() || !window()->isVisible() || window()->winId() == m_winId || !isEnabled() || !isVisible()) {
+        return false;
     }
 #if HAVE_XCB_COMPOSITE
     if (m_winId == XCB_WINDOW_NONE) {
-        return;
+        return false;
     }
     xcb_connection_t *c = QX11Info::connection();
 
@@ -868,6 +869,7 @@ void WindowThumbnail::startRedirecting()
 
     // redirect the window
     xcb_composite_redirect_window(c, m_winId, XCB_COMPOSITE_REDIRECT_AUTOMATIC);
+    m_redirecting = true;
 
     // generate the damage handle
     m_damage = xcb_generate_id(c);
@@ -883,6 +885,9 @@ void WindowThumbnail::startRedirecting()
     xcb_change_window_attributes(c, m_winId, XCB_CW_EVENT_MASK, &events);
     // force to update the texture
     m_damaged = true;
+    return true;
+#else
+    return false;
 #endif
 }
 
@@ -896,4 +901,16 @@ void WindowThumbnail::setThumbnailAvailable(bool thumbnailAvailable)
     }
 }
 
+void WindowThumbnail::sceneVisibilityChanged(bool visible)
+{
+    if (visible) {
+        if (startRedirecting()) {
+            update();
+        }
+    } else {
+        stopRedirecting();
+        releaseResources();
+    }
+}
+
 } // namespace
